-- -------------------------------------------------------------------------- --
-- CharScanner GearStats Enchantment Data                                     --
-- -------------------------------------------------------------------------- --
--                                                                            --
-- NOTE:                                                                      --
-- Enchantments with a special random effect like 'Enchant Weapon - Mongoose' --
-- [2673 / 27984] ('...occasionally increase Agility by 120 and attack speed  --
-- slightly...') are labeled as EFFECT.                                       --
--                                                                            --
-- -------------------------------------------------------------------------- --
--                                                                            --
-- Thanks: - Xinhuan                                                          --
--            I used the data from WoWEquip-v1.3 as a base, completed,        --
--            rearranged, added, reformated and tested everything.            --
--         - db.mmo-champion.com                                              --
--         - wowhead.com                                                      --
--                                                                            --
-- -------------------------------------------------------------------------- --

local EFFECT       = 0

local STRENGTH     = 1  -- "ITEM_MOD_STRENGTH_SHORT"
local AGILITY      = 2  -- "ITEM_MOD_AGILITY_SHORT"
local STAMINA      = 3  -- "ITEM_MOD_STAMINA_SHORT"
local INTELLECT    = 4  -- "ITEM_MOD_INTELLECT_SHORT"
local SPIRIT       = 5  -- "ITEM_MOD_SPIRIT_SHORT"

local ATTACKPOWER  = 6  -- "ITEM_MOD_ATTACK_POWER_SHORT"
local BLOCK        = 7  -- "ITEM_MOD_BLOCK_RATING_SHORT"
local DODGE        = 8  -- "ITEM_MOD_DODGE_RATING_SHORT"
local PARRY        = 9  -- "ITEM_MOD_PARRY_RATING_SHORT"
local HIT          = 10 -- "ITEM_MOD_HIT_RATING_SHORT"
local CRIT         = 11 -- "ITEM_MOD_CRIT_RATING_SHORT"
local HASTE        = 12 -- "ITEM_MOD_HASTE_RATING_SHORT"
local EXPERTISE    = 13 -- "ITEM_MOD_EXPERTISE_RATING_SHORT"
local MASTERY      = 14 -- "ITEM_MOD_MASTERY_RATING_SHORT"
local SPELLPOWER   = 15 -- "ITEM_MOD_SPELL_POWER_SHORT"

local PENETRATION  = 16 -- "ITEM_MOD_SPELL_PENETRATION_SHORT"
local RESILIENCE   = 17 -- "ITEM_MOD_RESILIENCE_RATING_SHORT"

local ARMOR        = 18 -- "RESISTANCE0_NAME" 
local HOLY_RES     = 19 -- "RESISTANCE1_NAME" - ITEM_MOD_HOLY_RESISTANCE_SHORT?  -> I have not seen this ingame
local FIRE_RES     = 20 -- "RESISTANCE2_NAME" - ITEM_MOD_FIRE_RESISTANCE_SHORT   -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local NATURE_RES   = 21 -- "RESISTANCE3_NAME" - ITEM_MOD_NATURE_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local FROST_RES    = 22 -- "RESISTANCE4_NAME" - ITEM_MOD_FROST_RESISTANCE_SHORT  -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local SHADOW_RES   = 23 -- "RESISTANCE5_NAME" - ITEM_MOD_SHADOW_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local ARCANE_RES   = 24 -- "RESISTANCE6_NAME" - ITEM_MOD_ARCANE_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua

local HEALTH       = 25 -- "ITEM_MOD_HEALTH_SHORT"
local MANA         = 26 -- "ITEM_MOD_MANA_SHORT"

local HASTE_RANGED = 27 -- "ITEM_MOD_HASTE_RANGED_RATING_SHORT"
local HIT_RANGED   = 28 -- "ITEM_MOD_HIT_RANGED_RATING_SHORT"
local CRIT_RANGED  = 29 -- "ITEM_MOD_CRIT_RANGED_RATING_SHORT"


local enchantIDs = {
-- ------------------------------------------------------------------------------------------------------------------ --
-- MULTI / OLD                                                                                                        --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Arcanums (Librams)
[1504]  = { 11643,    nil, 125, ARMOR}, -- Lesser Arcanum of Tenacity
[2545]  = { 18331,    nil, 12, DODGE}, -- Arcanum of Protection
[1505]  = { 11644,    nil, 20, FIRE_RES}, -- Lesser Arcanum of Resilience
[2543]  = { 18329,    nil, 10, HASTE}, -- Arcanum of Rapidity
[1503]  = { 11642,    nil, 100, HEALTH}, -- Lesser Arcanum of Constitution
[1483]  = { 11622,    nil, 150, MANA}, -- Lesser Arcanum of Rumination
[2544]  = { 18330,    nil, 8, SPELLPOWER}, -- Arcanum of Focus
[1506]  = { 11645,    nil, 8, STRENGTH}, -- Lesser Arcanum of Voracity (STRENGTH)
[1507]  = { 11646,    nil, 8, STAMINA}, -- Lesser Arcanum of Voracity (STAMINA)
[1508]  = { 11647,    nil, 8, AGILITY}, -- Lesser Arcanum of Voracity (AGILITY)
[1509]  = { 11648,    nil, 8, INTELLECT}, -- Lesser Arcanum of Voracity (INTELLECT)
[1510]  = { 11649,    nil, 8, SPIRIT}, -- Lesser Arcanum of Voracity (SPIRIT)

-- Zul'Gurub (Idols)
[2583]  = { 19782,    nil, 10, STAMINA, 10, DODGE, 10, PARRY}, -- Presence of Might (WARRIOR)
[2584]  = { 19783,    nil, 10, STAMINA, 10, DODGE, 10, INTELLECT}, -- Syncretist's Sigil (PALADIN)
[3755]  = { 19784,    nil, 28, ATTACKPOWER, 12, DODGE}, -- Death's Embrace (ROGUE)
[3754]  = { 19785,    nil, 24, ATTACKPOWER, 10, STAMINA, 10, HIT}, -- Falcon's Call (HUNTER)
[2587]  = { 19786,    nil, 15, INTELLECT, 13, SPELLPOWER}, -- Vodouisant's Vigilant Embrace (SHAMAN)
[2588]  = { 19787,    nil, 18, SPELLPOWER, 8, HIT}, -- Presence of Sight (MAGE)
[2589]  = { 19788,    nil, 10, STAMINA, 18, SPELLPOWER}, -- Hoodoo Hex (WARLOCK)
[2590]  = { 19789,    nil, 10, STAMINA, 13, SPELLPOWER, 10, SPIRIT}, -- Prophetic Aura (PRIEST)
[2591]  = { 19790,    nil, 10, STAMINA, 10, INTELLECT, 12, SPELLPOWER}, -- Animist's Caress (DRUID)
[2681]  = { 22635,    nil, 10, NATURE_RES}, -- Savage Guard

-- Argent Dawn (Insignias)
[2682]  = { 22636,    nil, 10, FROST_RES}, -- Ice Guard
[2683]  = { 22638,    nil, 10, SHADOW_RES}, -- Shadow Guard

-- Armor Kits
-- Cata ========================================
-- - Leatherworking
[4120]  = { 56477,    nil, 36, STAMINA}, -- Savage Armor Kit
[4121]  = { 56517,    nil, 44, STAMINA}, -- Heavy Savage Armor Kit
-- Wrath ========================================
-- - Leatherworking
[3329]  = { 38375,    nil, 12, STAMINA}, -- Borean Armor Kit
[3330]  = { 38376,    nil, 18, STAMINA}, -- Heavy Borean Armor Kit
-- BC ========================================
-- - Leatherworking
[2989]  = { 29488,    nil, 8, ARCANE_RES}, -- Arcane Armor Kit
[2793]  = { 25651,    nil, 8, DODGE}, -- Vindicator's Armor Kit
[2985]  = { 29485,    nil, 8, FIRE_RES}, -- Flame Armor Kit
[2987]  = { 29486,    nil, 8, FROST_RES}, -- Frost Armor Kit
[2988]  = { 29487,    nil, 8, NATURE_RES}, -- Nature Armor Kit
[2984]  = { 29483,    nil, 8, SHADOW_RES}, -- Shadow Armor Kit
[2792]  = { 25650,    nil, 8, STAMINA}, -- Knothide Armor Kit
[2841]  = { 34330,    nil, 10, STAMINA}, -- Heavy Knothide Armor Kit
[2794]  = { 25652,    nil, 8, SPIRIT}, -- Magister's Armor Kit
-- Classic ========================================
-- - Leatherworking
[15]    = {  2304,    nil, 8, ARMOR}, -- Light Armor Kit
[16]    = {  2313,    nil, 16, ARMOR}, -- Medium Armor Kit
[17]    = {  4265,    nil, 24, ARMOR}, -- Heavy Armor Kit
[18]    = {  8173,    nil, 32, ARMOR}, -- Thick Armor Kit
[1843]  = { 15564,    nil, 40, ARMOR}, -- Rugged Armor Kit
[2503]  = { 18251,    nil, 5, DODGE}, -- Core Armor Kit

-- ------------------------------------------------------------------------------------------------------------------ --
-- HEAD                                                                                                               --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Reputation Vendors
[4206]  = { 62366,    nil, 90, STAMINA, 35, DODGE}, -- Arcanum of the Earthen Ring
[4207]  = { 62367,    nil, 60, INTELLECT, 35, CRIT}, -- Arcanum of Hyjal
[4208]  = { 62422,  62368, 60, STRENGTH, 35, MASTERY}, -- 62422 (ALLIANCE) Arcanum of the Wildhammer / 62368 (HORDE) Arcanum of the Dragonmaw
[4209]  = { 62369,    nil, 60, AGILITY, 35, HASTE}, -- Arcanum of the Ramkahen
-- - PvP
[4246]  = { 68769,    nil, 60, AGILITY, 35, RESILIENCE}, -- Arcanum of Vicious Agility
[4245]  = { 68770,    nil, 60, INTELLECT, 35, RESILIENCE}, -- Arcanum of Vicious Intellect
[4247]  = { 68768,    nil, 60, STRENGTH, 35, RESILIENCE}, -- Arcanum of Vicious Strength
-- Wrath ========================================
-- - Reputation Vendors
[3817]  = { 50367,    nil, 50, ATTACKPOWER, 20, CRIT}, -- Arcanum of Torment (oldID: 44149)
[3820]  = { 50368,    nil, 26, INTELLECT, 20, CRIT}, -- Arcanum of Burning Mysteries (oldID: 44159)
[3819]  = { 50370,    nil, 26, INTELLECT, 20, SPIRIT}, -- Arcanum of Blissful Mending (oldID: 44152)
[3815]  = { 44140,    nil, 25, ARCANE_RES, 30, STAMINA}, -- Arcanum of the Eclipsed Moon
[3816]  = { 44141,    nil, 25, FIRE_RES, 30, STAMINA}, -- Arcanum of the Flame's Soul
[3812]  = { 44137,    nil, 25, FROST_RES, 30, STAMINA}, -- Arcanum of the Frosty Soul
[3813]  = { 44138,    nil, 25, NATURE_RES, 30, STAMINA}, -- Arcanum of Toxic Warding
[3814]  = { 44139,    nil, 25, SHADOW_RES, 30, STAMINA}, -- Arcanum of the Fleeing Shadow
[3818]  = { 50369,    nil, 37, STAMINA, 20, DODGE}, -- Arcanum of the Stalwart Protector (oldID: 44150)
-- - PvP
[3795]  = { 44069,    nil, 50, ATTACKPOWER, 20, RESILIENCE}, -- Arcanum of Triumph
[3797]  = { 44075,    nil, 29, SPELLPOWER, 20, RESILIENCE}, -- Arcanum of Dominance
[3842]  = { 44701,  44702, 30, STAMINA, 25, RESILIENCE}, -- 44701 (ALLIANCE), 44702 (HORDE) / 50372 (ALLIANCE), 50373 (HORDE) -- Arcanum of the Savage Gladiator
-- BC ========================================
-- - Reputation Vendors
[3006]  = { 29195,    nil, 20, ARCANE_RES}, -- Arcanum of Arcane Warding
[3003]  = { 29192,    nil, 34, ATTACKPOWER, 16, HIT}, -- Arcanum of Ferocity
[2999]  = { 29186,    nil, 16, PARRY, 17, DODGE}, -- Arcanum of the Defender
[3007]  = { 29196,    nil, 20, FIRE_RES}, -- Arcanum of Fire Warding
[3008]  = { 29198,    nil, 20, FROST_RES}, -- Arcanum of Frost Warding
[3001]  = { 29189,    nil, 16, INTELLECT, 18, SPIRIT}, -- Arcanum of Renewal
[3005]  = { 29194,    nil, 20, NATURE_RES}, -- Arcanum of Nature Warding
[3009]  = { 29199,    nil, 20, SHADOW_RES}, -- Arcanum of Shadow Warding
[3002]  = { 29191,    nil, 22, SPELLPOWER, 14, HIT}, -- Arcanum of Power
[3004]  = { 29193,    nil, 18, STAMINA, 20, RESILIENCE}, -- Arcanum of the Gladiator
[3096]  = { 30846,    nil, 17, STRENGTH, 16, INTELLECT}, -- Arcanum of the Outcast

-- ------------------------------------------------------------------------------------------------------------------ --
-- SHOULDER                                                                                                           --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Therazane
[4200]  = { 62343,    nil, 50, INTELLECT, 25, HASTE}, -- Greater Inscription of Charged Lodestone
[4202]  = { 62345,    nil, 50, STRENGTH, 25, CRIT}, -- Greater Inscription of Jagged Stone
[4204]  = { 62346,    nil, 50, AGILITY, 25, MASTERY}, -- Greater Inscription of Shattered Crystal
[4198]  = { 62333,    nil, 75, STAMINA, 25, DODGE}, -- Greater Inscription of Unbreakable Quartz
[4199]  = { 62342,    nil, 30, INTELLECT, 20, HASTE}, -- Lesser Inscription of Charged Lodestone
[4201]  = { 62344,    nil, 30, STRENGTH, 20, CRIT}, -- Lesser Inscription of Jagged Stone
[4205]  = { 62347,    nil, 30, AGILITY, 20, MASTERY}, -- Lesser Inscription of Shattered Crystal
[4197]  = { 62321,    nil, 45, STAMINA, 20, DODGE}, -- Lesser Inscription of Unbreakable Quartz
-- - Inscription Profession Only
[4196]  = {-86403,    nil, 130, INTELLECT, 25, HASTE}, -- Felfire Inscription
[4195]  = {-86402,    nil, 195, STAMINA, 25, DODGE}, -- Inscription of the Earth Prince
[4194]  = {-86401,    nil, 130, STRENGTH, 25, CRIT}, -- Lionsmane Inscription
[4193]  = {-86375,    nil, 130, AGILITY, 25, MASTERY}, -- Swiftsteel Inscription
-- - PvP
[4250]  = { 68774,    nil, 50, AGILITY, 25, RESILIENCE}, -- Greater Inscription of Vicious Agility
[4248]  = { 68772,    nil, 50, INTELLECT, 25, RESILIENCE}, -- Greater Inscription of Vicious Intellect
[4249]  = { 68773,    nil, 50, STRENGTH, 25, RESILIENCE}, -- Greater Inscription of Vicious Strength
-- Wrath ========================================
-- - Hodir Inscriptions
[3875]  = { 44131,    nil, 30, ATTACKPOWER, 10, CRIT}, -- Lesser Inscription of the Axe
[3808]  = { 44133,    nil, 40, ATTACKPOWER, 15, CRIT}, -- Greater Inscription of the Axe
[3876]  = { 44132,    nil, 15, DODGE, 10, PARRY}, -- Lesser Inscription of the Pinnacle
[3811]  = { 44136,    nil, 20, DODGE, 22, STAMINA}, -- Greater Inscription of the Pinnacle
[3806]  = { 44129,    nil, 18, SPELLPOWER, 10, CRIT}, -- Lesser Inscription of the Storm
[3810]  = { 44135,    nil, 24, SPELLPOWER, 15, CRIT}, -- Greater Inscription of the Storm
[3807]  = { 44130,    nil, 15, INTELLECT, 10, SPIRIT}, -- Lesser Inscription of the Crag
[3809]  = { 44134,    nil, 21, INTELLECT, 16, SPIRIT}, -- Greater Inscription of the Crag
-- - Inscription Profession Only
[3835]  = {-61117,    nil, 120, ATTACKPOWER, 15, CRIT}, -- Master's Inscription of the Axe
[3837]  = {-61119,    nil, 60, DODGE, 15, PARRY}, -- Master's Inscription of the Pinnacle
[3838]  = {-61120,    nil, 70, SPELLPOWER, 15, CRIT}, -- Master's Inscription of the Storm
[3836]  = {-61118,    nil, 60, INTELLECT, 15, SPIRIT}, -- Master's Inscription of the Crag
-- - PvP
[3793]  = { 44067,    nil, 40, ATTACKPOWER, 15, RESILIENCE}, -- Inscription of Triumph
[3794]  = { 44068,    nil, 23, SPELLPOWER, 15, RESILIENCE}, -- Inscription of Dominance
[3852]  = { 44957,    nil, 30, STAMINA, 15, RESILIENCE}, -- Greater Inscription of the Gladiator
-- BC ========================================
-- - Aldor Inscriptions
[2977]  = { 28882,    nil, 13, DODGE}, -- Inscription of Warding
[2978]  = { 28889,    nil, 15, DODGE, 15, STAMINA}, -- Greater Inscription of Warding
[2979]  = { 28878,    nil, 15, SPELLPOWER}, -- Inscription of Faith
[2980]  = { 28887,    nil, 15, INTELLECT, 10, SPIRIT}, -- Greater Inscription of Faith
[2981]  = { 28881,    nil, 15, SPELLPOWER}, -- Inscription of Discipline
[2982]  = { 28886,    nil, 18, SPELLPOWER, 10, CRIT}, -- Greater Inscription of Discipline
[2983]  = { 28885,    nil, 26, ATTACKPOWER}, -- Inscription of Vengeance
[2986]  = { 28888,    nil, 30, ATTACKPOWER, 10, CRIT}, -- Greater Inscription of Vengeance
-- - Scryer Inscriptions
[2990]  = { 28908,    nil, 13, DODGE}, -- Inscription of the Knight
[2991]  = { 28911,    nil, 15, PARRY, 10, DODGE}, -- Greater Inscription of the Knight
[2992]  = { 28904,    nil, 12, SPIRIT}, -- Inscription of the Oracle
[2993]  = { 28912,    nil, 16, SPIRIT, 10, INTELLECT}, -- Greater Inscription of the Oracle
[2994]  = { 28903,    nil, 13, CRIT}, -- Inscription of the Orb
[2995]  = { 28909,    nil, 15, CRIT, 12, SPELLPOWER}, -- Greater Inscription of the Orb
[2996]  = { 28907,    nil, 13, CRIT}, -- Inscription of the Blade
[2997]  = { 28910,    nil, 15, CRIT, 20, ATTACKPOWER}, -- Greater Inscription of the Blade
-- - Violet Eye Inscriptions
[2998]  = { 29187,    nil, 7, HOLY_RES, 7, FIRE_RES, 7, NATURE_RES, 7, FROST_RES, 7, SHADOW_RES, 7, ARCANE_RES}, -- Inscription of Endurance
-- Classic ========================================
-- - Argent Dawn Mantles
[2483]  = { 18169,    nil, 5, FIRE_RES}, -- Flame Mantle of the Dawn
[2484]  = { 18170,    nil, 5, FROST_RES}, -- Frost Mantle of the Dawn
[2485]  = { 18171,    nil, 5, ARCANE_RES}, -- Arcane Mantle of the Dawn
[2486]  = { 18172,    nil, 5, NATURE_RES}, -- Nature Mantle of the Dawn
[2487]  = { 18173,    nil, 5, SHADOW_RES}, -- Shadow Mantle of the Dawn
[2488]  = { 18182,    nil, 5, HOLY_RES, 5, FIRE_RES, 5, NATURE_RES, 5, FROST_RES, 5, SHADOW_RES, 5, ARCANE_RES}, -- Chromatic Mantle of the Dawn
-- - Zul'Gurub Signets
[2604]  = { 20078,    nil, 18, SPELLPOWER}, -- Zandalar Signet of Serenity
[2605]  = { 20076,    nil, 18, SPELLPOWER}, -- Zandalar Signet of Mojo
[2606]  = { 20077,    nil, 30, ATTACKPOWER}, -- Zandalar Signet of Might
-- - Naxxramas Sapphiron Drops
[2715]  = { 23547,    nil, 16, SPELLPOWER}, -- Resilience of the Scourge
[2716]  = { 23549,    nil, 16, STAMINA, 100, ARMOR}, -- Fortitude of the Scourge
[2717]  = { 23548,    nil, 26, ATTACKPOWER, 14, CRIT}, -- Might of the Scourge
[2721]  = { 23545,    nil, 15, SPELLPOWER, 14, CRIT}, -- Power of the Scourge

-- ------------------------------------------------------------------------------------------------------------------ --
-- CHEST                                                                                                              --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting
[4063]  = {-74191,    nil, 15, STRENGTH, 15, AGILITY, 15, STAMINA, 15, INTELLECT, 15, SPIRIT}, -- Enchant Chest - Mighty Stats
[4070]  = {-74200,    nil, 55, STAMINA}, -- Enchant Chest - Stamina
[4077]  = {-74214,    nil, 40, RESILIENCE}, -- Enchant Chest - Mighty Resilience
[4088]  = {-74231,    nil, 40, SPIRIT}, -- Enchant Chest - Exceptional Spirit
[4103]  = {-74251,    nil, 75, STAMINA}, -- Enchant Chest - Greater Stamina
[4102]  = {-74250,    nil, 20, STRENGTH, 20, AGILITY, 20, STAMINA, 20, INTELLECT, 20, SPIRIT}, -- Enchant Chest - Peerless Stats
-- Wrath ========================================
-- - Enchanting
[3252]  = {-44623,    nil, 8, STRENGTH, 8, AGILITY, 8, STAMINA, 8, INTELLECT, 8, SPIRIT}, -- Enchant Chest - Super Stats
[3832]  = {-60692,    nil, 10, STRENGTH, 10, AGILITY, 10, STAMINA, 10, INTELLECT, 10, SPIRIT}, -- Enchant Chest - Powerful Stats
[1953]  = {-47766,    nil, 22, DODGE}, -- Enchant Chest - Greater Defense
[3236]  = {-44492,    nil, 200, HEALTH}, -- Enchant Chest - Mighty Health
[3297]  = {-47900,    nil, 275, HEALTH}, -- Enchant Chest - Super Health
[3233]  = {-27958,    nil, 250, MANA}, -- Enchant Chest - Exceptional Mana
[3245]  = {-44588,    nil, 20, RESILIENCE}, -- Enchant Chest - Exceptional Resilience
[2381]  = {-44509,    nil, 20, SPIRIT}, -- Enchant Chest - Greater Mana Restoration
-- BC ========================================
-- - Enchanting
[2661]  = {-27960,    nil, 6, STRENGTH, 6, AGILITY, 6, STAMINA, 6, INTELLECT, 6, SPIRIT}, -- Enchant Chest - Exceptional Stats
[1951]  = {-46594,    nil, 16, DODGE}, -- Enchant Chest - Defense
[2659]  = {-27957,    nil, 150, HEALTH}, -- Enchant Chest - Exceptional Health
[2933]  = {-33992,    nil, 15, RESILIENCE}, -- Enchant Chest - Major Resilience
[1144]  = {-33990,    nil, 15, SPIRIT}, -- Enchant Chest - Major Spirit
-- TODO [3150]  = {-33991,    nil}, -- Enchant Chest - Restore Mana Prime
-- TODO [2376]  = {-33991,    nil}, -- Enchant Chest - Restore Mana Prime
-- Classic
-- TODO [44]    = { -7426,    nil}, -- Enchant Chest - Minor Absorption
-- TODO [63]    = {-13538,    nil}, -- Enchant Chest - Lesser Absorption
[847]   = {-13626,    nil, 1, STRENGTH, 1, AGILITY, 1, STAMINA, 1, INTELLECT, 1, SPIRIT}, -- Enchant Chest - Minor Stats
[866]   = {-13700,    nil, 2, STRENGTH, 2, AGILITY, 2, STAMINA, 2, INTELLECT, 2, SPIRIT}, -- Enchant Chest - Lesser Stats
[928]   = {-13941,    nil, 3, STRENGTH, 3, AGILITY, 3, STAMINA, 3, INTELLECT, 3, SPIRIT}, -- Enchant Chest - Stats
[1891]  = {-20025,    nil, 4, STRENGTH, 4, AGILITY, 4, STAMINA, 4, INTELLECT, 4, SPIRIT}, -- Enchant Chest - Greater Stats
[41]    = { -7418,    nil, 5, HEALTH}, -- Enchant Chest - Minor Health
[242]   = { -7748,    nil, 15, HEALTH}, -- Enchant Chest - Lesser Health
[254]   = { -7857,    nil, 25, HEALTH}, -- Enchant Chest - Health
[850]   = {-13640,    nil, 35, HEALTH}, -- Enchant Chest - Greater Health
[908]   = {-13858,    nil, 50, HEALTH}, -- Enchant Chest - Superior Health
[1892]  = {-20026,    nil, 100, HEALTH}, -- Enchant Chest - Major Health
[24]    = { -7443,    nil, 5, MANA}, -- Enchant Chest - Minor Mana
[246]   = { -7776,    nil, 20, MANA}, -- Enchant Chest - Lesser Mana
[843]   = {-13607,    nil, 30, MANA}, -- Enchant Chest - Mana
[857]   = {-13663,    nil, 50, MANA}, -- Enchant Chest - Greater Mana
[913]   = {-13917,    nil, 65, MANA}, -- Enchant Chest - Superior Mana
[1893]  = {-20028,    nil, 100, MANA}, -- Enchant Chest - Major Mana

-- ------------------------------------------------------------------------------------------------------------------ --
-- LEGS                                                                                                               --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Leatherworking
[4127]  = { 56551,    nil, 145, STAMINA, 55, AGILITY}, -- Charscale Leg Armor
[4126]  = { 56550,    nil, 190, ATTACKPOWER, 55, CRIT}, -- Dragonscale Leg Armor
[4122]  = { 56502,    nil, 110, ATTACKPOWER, 45, CRIT}, -- Scorched Leg Armor
[4124]  = { 56503,    nil, 85, STAMINA, 45, AGILITY}, -- Twilight Leg Armor
-- - Leatherworkers Only
--[4127]  = {-85068,    nil, 145, STAMINA, 55, AGILITY}, -- Charscale Leg Reinforcements   ---same enchantID as Leatherworking---
--[4126]  = {-85067,    nil, 190, ATTACKPOWER, 55, CRIT}, -- Dragonbone Leg Reinforcements   ---same enchantID as Leatherworking---
[4270]  = { 71720,    nil, 145, STAMINA, 55, DODGE}, -- Drakehide Leg Reinforcements
-- - Tailoring
[4112]  = { 54448,    nil, 95, INTELLECT, 80, STAMINA}, -- Powerful Enchanted Spellthread
[4110]  = { 54450,    nil, 95, INTELLECT, 55, SPIRIT}, -- Powerful Ghostly Spellthread
[4111]  = { 54447,    nil, 55, INTELLECT, 65, STAMINA}, -- Enchanted Spellthread
[4109]  = { 54449,    nil, 55, INTELLECT, 45, SPIRIT}, -- Ghostly Spellthread
-- - Tailors Only
[4114]  = {-75155,    nil, 95, INTELLECT, 55, SPIRIT}, -- Sanctified Spellthread (Rank 2)
[4113]  = {-75154,    nil, 95, INTELLECT, 80, STAMINA}, -- Master's Spellthread (Rank 2)
-- Wrath ========================================
-- - Leatherworking
[3326]  = { 38372,    nil, 55, ATTACKPOWER, 15, CRIT}, -- Nerubian Leg Armor
[3823]  = { 38374,    nil, 75, ATTACKPOWER, 22, CRIT}, -- Icescale Leg Armor
[3853]  = { 44963,    nil, 40, RESILIENCE, 28, STAMINA}, -- Earthen Leg Armor
[3325]  = { 38371,    nil, 45, STAMINA, 15, AGILITY}, -- Jormungar Leg Armor
[3822]  = { 38373,    nil, 55, STAMINA, 22, AGILITY}, -- Frosthide Leg Armor
-- - Leatherworkers Only
[3328]  = {-60584,    nil, 75, ATTACKPOWER, 22, CRIT}, -- Nerubian Leg Reinforcements
[3327]  = {-60583,    nil, 55, STAMINA, 55, AGILITY}, -- Jormungar Leg Reinforcements
[3332]  = { 38378,    nil, 100, ATTACKPOWER, 36, CRIT}, -- Wyrmscale Leg Armor
-- - Tailoring
[3718]  = { 41601,    nil, 35, SPELLPOWER, 12, SPIRIT}, -- Shining Spellthread
[3720]  = { 41603,    nil, 35, SPELLPOWER, 20, STAMINA}, -- Azure Spellthread
[3719]  = { 41602,    nil, 50, SPELLPOWER, 20, SPIRIT}, -- Brilliant Spellthread
[3721]  = { 41604,    nil, 50, SPELLPOWER, 30, STAMINA}, -- Sapphire Spellthread
-- - Tailors Only
[3872]  = {-56039,    nil, 50, SPELLPOWER, 20, SPIRIT}, -- Sanctified Spellthread (Rank 1)
[3873]  = {-56034,    nil, 50, SPELLPOWER, 30, STAMINA}, -- Master's Spellthread (Rank 1)
-- BC ========================================
-- - Leatherworking
[3010]  = { 29533,    nil, 40, ATTACKPOWER, 10, CRIT}, -- Cobrahide Leg Armor
[3012]  = { 29535,    nil, 50, ATTACKPOWER, 12, CRIT}, -- Nethercobra Leg Armor
[3011]  = { 29534,    nil, 30, STAMINA, 10, AGILITY}, -- Clefthide Leg Armor
[3013]  = { 29536,    nil, 40, STAMINA, 12, AGILITY}, -- Nethercleft Leg Armor
-- - Tailoring
[2745]  = { 24275,    nil, 25, SPELLPOWER, 15, STAMINA}, -- Silver Spellthread
[2747]  = { 24273,    nil, 25, SPELLPOWER, 15, STAMINA}, -- Mystic Spellthread
[2746]  = { 24276,    nil, 35, SPELLPOWER, 20, STAMINA}, -- Golden Spellthread
[2748]  = { 24274,    nil, 35, SPELLPOWER, 20, STAMINA}, -- Runic Spellthread

-- ------------------------------------------------------------------------------------------------------------------ --
-- FEET                                                                                                               --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting
[4105]  = {-74252,    nil, 25, AGILITY, 0, EFFECT}, -- Enchant Boots - Assassin's Step
[4062]  = {-74189,    nil, 30, STAMINA, 0, EFFECT}, -- Enchant Boots - Earthen Vitality
[4069]  = {-74199,    nil, 50, HASTE}, -- Enchant Boots - Haste
[4104]  = {-74253,    nil, 35, MASTERY, 0, EFFECT}, -- Enchant Boots - Lavawalker
[4076]  = {-74213,    nil, 35, AGILITY}, -- Enchant Boots - Major Agility
[4094]  = {-74238,    nil, 50, MASTERY}, -- Enchant Boots - Mastery
[4092]  = {-74236,    nil, 50, HIT}, -- Enchant Boots - Precision
-- Wrath ========================================
-- - Enchanting
[983]   = {-44589,    nil, 16, AGILITY}, -- Enchant Boots - Superior Agility
[3824]  = {-60606,    nil, 24, ATTACKPOWER}, -- Enchant Boots - Assault
[1597]  = {-60763,    nil, 32, ATTACKPOWER}, -- Enchant Boots - Greater Assault
[3826]  = {-60623,    nil, 12, HIT, 12, CRIT}, -- Enchant Boots - Icewalker
[3858]  = {-63746,    nil, 5, HIT}, -- Enchant Boots - Lesser Accuracy
[3232]  = {-47901,    nil, 15, STAMINA, 0, EFFECT}, -- Enchant Boots - Tuskarr's Vitality
[1147]  = {-44508,    nil, 18, SPIRIT}, -- Enchant Boots - Greater Spirit
[1075]  = {-44528,    nil, 22, STAMINA}, -- Enchant Boots - Greater Fortitude
-- TODO [3244]  = {-44584,    nil}, -- Enchant Boots - Greater Vitality
-- BC ========================================
-- - Enchanting
[2657]  = {-27951,    nil, 12, AGILITY}, -- Enchant Boots - Dexterity
[2658]  = {-27954,    nil, 10, HIT, 10, CRIT}, -- Enchant Boots - Surefooted
[2939]  = {-34007,    nil, 6, AGILITY, 0, EFFECT}, -- Enchant Boots - Cat's Swiftness
[2940]  = {-34008,    nil, 9, STAMINA, 0, EFFECT}, -- Enchant Boots - Boar's Speed
[2649]  = {-27950,    nil, 12, STAMINA}, -- Enchant Boots - Fortitude
-- TODO [2656]  = {-27948,    nil}, -- Enchant Boots - Vitality
-- Classic ========================================
-- - Enchanting
[247]   = { -7867,    nil, 1, AGILITY}, -- Enchant Boots - Minor Agility
[849]   = {-13637,    nil, 3, AGILITY}, -- Enchant Boots - Lesser Agility
[904]   = {-13935,    nil, 5, AGILITY}, -- Enchant Boots - Agility
[1887]  = {-20023,    nil, 7, AGILITY}, -- Enchant Boots - Greater Agility   ---same enchantID as Enchant Gloves - Greater Agility!---
[911]   = {-13890,    nil, 0, EFFECT}, -- Enchant Boots - Minor Speed
[66]    = { -7863,    nil, 1, STAMINA}, -- Enchant Boots - Minor Stamina
[724]   = {-13644,    nil, 3, STAMINA}, -- Enchant Boots - Lesser Stamina
[852]   = {-13836,    nil, 5, STAMINA}, -- Enchant Boots - Stamina
[929]   = {-20020,    nil, 7, STAMINA}, -- Enchant Boots - Greater Stamina
[255]   = {-13687,    nil, 3, SPIRIT}, -- Enchant Boots - Lesser Spirit
[851]   = {-20024,    nil, 5, SPIRIT}, -- Enchant Boots - Spirit
-- - Blacksmithing
[464]   = {  7969,    nil, 0, EFFECT}, -- Mithril Spurs

-- ------------------------------------------------------------------------------------------------------------------ --
-- WRIST                                                                                                              --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting
[4258]  = {-96264,    nil, 50, AGILITY}, -- Enchant Bracer - Agility
[4256]  = {-96261,    nil, 50, STRENGTH}, -- Enchant Bracer - Major Strength
[4257]  = {-96262,    nil, 50, INTELLECT}, -- Enchant Bracer - Mighty Intellect
[4065]  = {-74193,    nil, 50, HASTE}, -- Enchant Bracer - Speed
[4071]  = {-74201,    nil, 50, CRIT}, -- Enchant Bracer - Critical Strike
[4086]  = {-74229,    nil, 50, DODGE}, -- Enchant Bracer - Dodge
[4089]  = {-74232,    nil, 50, HIT}, -- Enchant Bracer - Precision
[4093]  = {-74237,    nil, 50, SPIRIT}, -- Enchant Bracer - Exceptional Spirit
[4095]  = {-74239,    nil, 50, EXPERTISE}, -- Enchant Bracer - Greater Expertise
[4101]  = {-74248,    nil, 65, CRIT}, -- Enchant Bracer - Greater Critical Strike
[4108]  = {-74256,    nil, 65, HASTE}, -- Enchant Bracer - Greater Speed
-- - Leatherworkers Only
[4189]  = {-85007,    nil, 195, STAMINA}, -- Draconic Embossment - Stamina
[4190]  = {-85008,    nil, 130, AGILITY}, -- Draconic Embossment - Agility
[4191]  = {-85009,    nil, 130, STRENGTH}, -- Draconic Embossment - Strength
[4192]  = {-85010,    nil, 130, INTELLECT}, -- Draconic Embossment - Intellect
-- Wrath ========================================
-- - Enchanting
[2661]  = {-44616,    nil, 6, STRENGTH, 6, AGILITY, 6, STAMINA, 6, INTELLECT, 6, SPIRIT}, -- Enchant Bracers - Greater Stats
[1600]  = {-60616,    nil, 38, ATTACKPOWER}, -- Enchant Bracers - Striking
[3845]  = {-44575,    nil, 50, ATTACKPOWER}, -- Enchant Bracers - Greater Assault
[3231]  = {-44598,    nil, 15, EXPERTISE}, -- Enchant Bracers - Expertise
[1119]  = {-44555,    nil, 16, INTELLECT}, -- Enchant Bracers - Exceptional Intellect
[2326]  = {-44635,    nil, 23, SPELLPOWER}, -- Enchant Bracers - Greater Spellpower
[2332]  = {-60767,    nil, 30, SPELLPOWER}, -- Enchant Bracers - Superior Spellpower
[1147]  = {-44593,    nil, 18, SPIRIT}, -- Enchant Bracers - Major Spirit
[3850]  = {-62256,    nil, 40, STAMINA}, -- Enchant Bracers - Major Stamina
-- - Leatherworkers Only
[3763]  = {-57701,    nil, 70, ARCANE_RES}, -- Fur Lining - Arcane Resist
[3756]  = {-57683,    nil, 130, ATTACKPOWER}, -- Fur Lining - Attack Power
[3759]  = {-57692,    nil, 70, FIRE_RES}, -- Fur Lining - Fire Resist
[3760]  = {-57694,    nil, 70, FROST_RES}, -- Fur Lining - Frost Resist
[3762]  = {-57699,    nil, 70, NATURE_RES}, -- Fur Lining - Nature Resist
[3761]  = {-57696,    nil, 70, SHADOW_RES}, -- Fur Lining - Shadow Resist
[3758]  = {-57691,    nil, 76, SPELLPOWER}, -- Fur Lining - Spell Power
[3757]  = {-57690,    nil, 102, STAMINA}, -- Fur Lining - Stamina
-- BC ========================================
-- - Enchanting
[1891]  = {-27905,    nil, 4, STRENGTH, 4, AGILITY, 4, STAMINA, 4, INTELLECT, 4, SPIRIT}, -- Enchant Bracer - Stats
[1593]  = {-34002,    nil, 24, ATTACKPOWER}, -- Enchant Bracer - Assault
[2648]  = {-27906,    nil, 12, DODGE}, -- Enchant Bracer - Major Defense
[369]   = {-34001,    nil, 12, INTELLECT}, -- Enchant Bracer - Major Intellect
[2650]  = {-27917,    nil, 15, SPELLPOWER}, -- Enchant Bracer - Spellpower
[2650]  = {-27911,    nil, 15, SPELLPOWER}, -- Enchant Bracer - Superior Healing
[2649]  = {-27914,    nil, 12, STAMINA}, -- Enchant Bracer - Fortitude
[2647]  = {-27899,    nil, 12, STRENGTH}, -- Enchant Bracer - Brawn
-- TODO [2679]  = {-27913,    nil}, -- Enchant Bracer - Restore Mana Prime
-- Classic ========================================
-- - Enchanting
[247]   = { -7779,    nil, 1, AGILITY}, -- Enchant Bracer - Minor Agility
[924]   = { -7428,    nil, 2, DODGE}, -- Enchant Bracer - Minor Deflection
[925]   = {-13646,    nil, 3, DODGE}, -- Enchant Bracer - Lesser Deflection
[923]   = {-13931,    nil, 5, DODGE}, -- Enchant Bracer - Deflection
[723]   = {-13622,    nil, 3, INTELLECT}, -- Enchant Bracer - Lesser Intellect
[905]   = {-13822,    nil, 5, INTELLECT}, -- Enchant Bracer - Intellect
[1883]  = {-20008,    nil, 7, INTELLECT}, -- Enchant Bracer - Greater Intellect
[41]    = { -7418,    nil, 5, HEALTH}, -- Enchant Bracer - Minor Health
[2650]  = {-23802,    nil, 15, SPELLPOWER}, -- Enchant Bracer - Healing Power
[243]   = { -7766,    nil, 1, SPIRIT}, -- Enchant Bracer - Minor Spirit
[255]   = { -7859,    nil, 3, SPIRIT}, -- Enchant Bracer - Lesser Spirit
[851]   = {-13642,    nil, 5, SPIRIT}, -- Enchant Bracer - Spirit
[907]   = {-13846,    nil, 7, SPIRIT}, -- Enchant Bracer - Greater Spirit
[1884]  = {-20009,    nil, 9, SPIRIT}, -- Enchant Bracer - Superior Spirit
[66]    = { -7457,    nil, 1, STAMINA}, -- Enchant Bracer - Minor Stamina
[724]   = {-13501,    nil, 3, STAMINA}, -- Enchant Bracer - Lesser Stamina
[852]   = {-13648,    nil, 5, STAMINA}, -- Enchant Bracer - Stamina
[929]   = {-13945,    nil, 7, STAMINA}, -- Enchant Bracer - Greater Stamina
[1886]  = {-20011,    nil, 9, STAMINA}, -- Enchant Bracer - Superior Stamina
[248]   = { -7782,    nil, 1, STRENGTH}, -- Enchant Bracer - Minor Strength
[823]   = {-13536,    nil, 3, STRENGTH}, -- Enchant Bracer - Lesser Strength
[856]   = {-13661,    nil, 5, STRENGTH}, -- Enchant Bracer - Strength
[927]   = {-13939,    nil, 7, STRENGTH}, -- Enchant Bracer - Greater Strength
[1885]  = {-20010,    nil, 9, STRENGTH}, -- Enchant Bracer - Superior Strength
-- TODO [2565]  = {-23801,    nil}, -- Enchant Bracer - Mana Regeneration

-- ------------------------------------------------------------------------------------------------------------------ --
-- HAND                                                                                                               --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting
[4075]  = {-74212,    nil, 35, STRENGTH}, -- Enchant Gloves - Exceptional Strength
[4082]  = {-74220,    nil, 50, EXPERTISE}, -- Enchant Gloves - Greater Expertise
[4107]  = {-74255,    nil, 65, MASTERY}, -- Enchant Gloves - Greater Mastery
[4068]  = {-74198,    nil, 50, HASTE}, -- Enchant Gloves - Haste
[4061]  = {-74132,    nil, 50, MASTERY}, -- Enchant Gloves - Mastery
[4106]  = {-74254,    nil, 50, STRENGTH}, -- Enchant Gloves - Mighty Strength
-- - Engineers Only
[4179]  = {-82175,    nil, 0, EFFECT}, -- Synapse Springs
[4180]  = {-82177,    nil, 0, EFFECT}, -- Quickflip Deflection Plates
[4181]  = {-82180,    nil, 0, EFFECT}, -- Tazik Shocker
[4182]  = {-82200,    nil, 0, EFFECT}, -- Spinal Healing Injector
[4183]  = {-82201,    nil, 0, EFFECT}, -- Z50 Mana Gulper
-- Wrath ========================================
-- - Enchanting
[3222]  = {-44529,    nil, 20, AGILITY}, -- Enchant Gloves - Major Agility
[3829]  = {-44513,    nil, 35, ATTACKPOWER}, -- Enchant Gloves - Greater Assault
[1603]  = {-60668,    nil, 44, ATTACKPOWER}, -- Enchant Gloves - Crusher
[3231]  = {-44484,    nil, 15, EXPERTISE}, -- Enchant Gloves - Expertise
[3238]  = {-44506,    nil, 0, EFFECT}, -- Enchant Gloves - Gatherer
[3234]  = {-44488,    nil, 20, HIT}, -- Enchant Gloves - Precision
[3253]  = {-44625,    nil, 10, PARRY, 0, EFFECT}, -- Enchant Gloves - Armsman
[3246]  = {-44592,    nil, 28, SPELLPOWER}, -- Enchant Gloves - Exceptional Spellpower
[846]   = {-71692,    nil, 0, EFFECT}, -- Enchant Gloves - Angler (+5 Fishing)    ---same enchantID as High Test Eternium Fishing Line (+5 Fishing)!---
-- - Engineers Only
[3860]  = {-63770,    nil, 0, EFFECT}, -- Reticulated Armor Webbing
[3604]  = {-54999,    nil, 0, EFFECT}, -- Hyperspeed Accelerators
[3603]  = {-54998,    nil, 0, EFFECT}, -- Hand-Mounted Pyro Rocket
-- BC ========================================
-- - Enchanting
[1594]  = {-33996,    nil, 26, ATTACKPOWER}, -- Enchant Gloves - Assault
[2934]  = {-33993,    nil, 10, CRIT}, -- Enchant Gloves - Blasting
[2935]  = {-33994,    nil, 15, HIT}, -- Enchant Gloves - Precise Strike
[2322]  = {-33999,    nil, 19, SPELLPOWER}, -- Enchant Gloves - Major Healing
[2937]  = {-33997,    nil, 20, SPELLPOWER}, -- Enchant Gloves - Major Spellpower
[684]   = {-33995,    nil, 15, STRENGTH}, -- Enchant Gloves - Major Strength
-- - Leatherworking
[3260]  = { 34207,    nil, 240, ARMOR}, -- Glove Reinforcements
-- Classic ========================================
-- - Enchanting
[904]   = {-13815,    nil, 5, AGILITY}, -- Enchant Gloves - Agility
[1887]  = {-20012,    nil, 7, AGILITY}, -- Enchant Gloves - Greater Agility   ---same enchantID as Enchant Boots - Greater Agility!---
[2564]  = {-25080,    nil, 15, AGILITY}, -- Enchant Gloves - Superior Agility
-- TODO [2616]  = {-25078,    nil}, -- Enchant Gloves - Fire Power
[2603]  = {-13620,    nil, 0, EFFECT}, -- Enchant Gloves - Fishing (+2 Fishing)
-- TODO [2615]  = {-25074,    nil}, -- Enchant Gloves - Frost Power
[931]   = {-13948,    nil, 10, HASTE}, -- Enchant Gloves - Minor Haste
[845]   = {-13617,    nil, 0, EFFECT}, -- Enchant Gloves - Herbalism
[909]   = {-13868,    nil, 0, EFFECT}, -- Enchant Gloves - Advanced Herbalism
[844]   = {-13612,    nil, 0, EFFECT}, -- Enchant Gloves - Mining
[906]   = {-13841,    nil, 0, EFFECT}, -- Enchant Gloves - Advanced Mining
[930]   = {-13947,    nil, 0, EFFECT}, -- Enchant Gloves - Riding Skill
-- TODO [2614]  = {-25073,    nil}, -- Enchant Gloves - Shadow Power
[2617]  = {-25079,    nil, 16, SPELLPOWER}, -- Enchant Gloves - Healing Power
[865]   = {-13698,    nil, 0, EFFECT}, -- Enchant Gloves - Skinning
[856]   = {-13887,    nil, 5, STRENGTH}, -- Enchant Gloves - Strength
[927]   = {-20013,    nil, 7, STRENGTH}, -- Enchant Gloves - Greater Strength
[2613]  = {-25072,    nil, 0, EFFECT}, -- Enchant Gloves - Threat

-- ------------------------------------------------------------------------------------------------------------------ --
-- FINGER                                                                                                             --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanters Only
[4078]  = {-74215,    nil, 40, STRENGTH}, -- Enchant Ring - Strength
[4079]  = {-74216,    nil, 40, AGILITY}, -- Enchant Ring - Agility
[4080]  = {-74217,    nil, 40, INTELLECT}, -- Enchant Ring - Intellect
[4081]  = {-74218,    nil, 60, STAMINA}, -- Enchant Ring - Greater Stamina
-- Wrath ========================================
-- - Enchanters Only
[3839]  = {-44645,    nil, 40, ATTACKPOWER}, -- Enchant Ring - Assault
[3840]  = {-44636,    nil, 23, SPELLPOWER}, -- Enchant Ring - Greater Spellpower
[3791]  = {-59636,    nil, 30, STAMINA}, -- Enchant Ring - Stamina
-- BC ========================================
-- - Enchanters Only
[2928]  = {-27924,    nil, 12, SPELLPOWER}, -- Enchant Ring - Spellpower
-- TODO [2929] = {-27920,    nil}, -- Enchant Ring - Striking
[2930]  = {-27926,    nil, 12, SPELLPOWER}, -- Enchant Ring - Healing Power
[2931]  = {-27927,    nil, 4, STRENGTH, 4, AGILITY, 4, STAMINA, 4, INTELLECT, 4, SPIRIT}, -- Enchant Ring - Stats

-- ------------------------------------------------------------------------------------------------------------------ --
-- CLOAK                                                                                                              --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting
[4064]  = {-74192,    nil, 70, PENETRATION}, -- Enchant Cloak - Greater Spell Piercing
[4072]  = {-74202,    nil, 30, INTELLECT}, -- Enchant Cloak - Intellect
[4087]  = {-74230,    nil, 50, CRIT}, -- Enchant Cloak - Critical Strike
[4090]  = {-74234,    nil, 250, ARMOR}, -- Enchant Cloak - Protection
[4096]  = {-74240,    nil, 50, INTELLECT}, -- Enchant Cloak - Greater Intellect
[4100]  = {-74247,    nil, 65, CRIT}, -- Enchant Cloak - Greater Critical Strike
-- - Tailors Only
[4118]  = {-75178,    nil, 0, EFFECT}, -- Swordguard Embroidery (Rank 2)
[4116]  = {-75175,    nil, 0, EFFECT}, -- Darkglow Embroidery (Rank 2)
[4115]  = {-75172,    nil, 0, EFFECT}, -- Lightweave Embroidery (Rank 2)
-- Wrath ========================================
-- - Enchanting
[3256]  = {-44631,    nil, 10, AGILITY, 40, ARMOR, 0, EFFECT}, -- Enchant Cloak - Shadow Armor
[983]   = {-44500,    nil, 16, AGILITY}, -- Enchant Cloak - Superior Agility
[1099]  = {-60663,    nil, 22, AGILITY}, -- Enchant Cloak - Major Agility
[1262]  = {-44596,    nil, 20, ARCANE_RES}, -- Enchant Cloak - Superior Arcane Resistance
[3294]  = {-47672,    nil, 225, ARMOR}, -- Enchant Cloak - Mighty Armor
[1951]  = {-44591,    nil, 16, DODGE}, -- Enchant Cloak - Titanweave
[1354]  = {-44556,    nil, 20, FIRE_RES}, -- Enchant Cloak - Superior Fire Resistance
[3230]  = {-44483,    nil, 20, FROST_RES}, -- Enchant Cloak - Superior Frost Resistance
[3825]  = {-60609,    nil, 15, HASTE}, -- Enchant Cloak - Speed
[3831]  = {-47898,    nil, 23, HASTE}, -- Enchant Cloak - Greater Speed
[1400]  = {-44494,    nil, 20, NATURE_RES}, -- Enchant Cloak - Superior Nature Resistance
[1446]  = {-44590,    nil, 20, SHADOW_RES}, -- Enchant Cloak - Superior Shadow Resistance
[3243]  = {-44582,    nil, 35, PENETRATION}, -- Enchant Cloak - Spell Piercing
[3296]  = {-47899,    nil, 10, SPIRIT, 0, EFFECT}, -- Enchant Cloak - Wisdom
-- - Tailors Only
[3730]  = {-55777,    nil, 0, EFFECT}, -- Swordguard Embroidery (Rank 1)
[3728]  = {-55769,    nil, 0, EFFECT}, -- Darkglow Embroidery (Rank 1)
[3722]  = {-55642,    nil, 0, EFFECT}, -- Lightweave Embroidery (Rank 1)
-- - Engineers Only
[3605]  = {-55002,    nil, 0, EFFECT}, -- Flexweave Underlay
[3859]  = {-63765,    nil, 0, EFFECT}, -- Springy Arachnoweave
-- BC ========================================
-- - Enchanting
[368]   = {-34004,    nil, 12, AGILITY}, -- Enchant Cloak - Greater Agility
[2664]  = {-27962,    nil, 7, HOLY_RES, 7, FIRE_RES, 7, NATURE_RES, 7, FROST_RES, 7, SHADOW_RES, 7, ARCANE_RES}, -- Enchant Cloak - Major Resistance
[1257]  = {-34005,    nil, 15, ARCANE_RES}, -- Enchant Cloak - Greater Arcane Resistance
[2662]  = {-27961,    nil, 120, ARMOR}, -- Enchant Cloak - Major Armor
[2648]  = {-47051,    nil, 12, DODGE}, -- Enchant Cloak - Steelweave
[2622]  = {-25086,    nil, 12, DODGE}, -- Enchant Cloak - Dodge
[1441]  = {-34006,    nil, 15, SHADOW_RES}, -- Enchant Cloak - Greater Shadow Resistance
[2938]  = {-34003,    nil, 20, PENETRATION}, -- Enchant Cloak - Spell Penetration
-- Classic ========================================
-- - Enchanting
[247]   = {-13419,    nil, 1, AGILITY}, -- Enchant Cloak - Minor Agility
[849]   = {-13882,    nil, 3, AGILITY}, -- Enchant Cloak - Lesser Agility
[65]    = { -7454,    nil, 1, HOLY_RES, 1, FIRE_RES, 1, NATURE_RES, 1, FROST_RES, 1, SHADOW_RES, 1, ARCANE_RES}, -- Enchant Cloak - Minor Resistance
[903]   = {-13794,    nil, 3, HOLY_RES, 3, FIRE_RES, 3, NATURE_RES, 3, FROST_RES, 3, SHADOW_RES, 3, ARCANE_RES}, -- Enchant Cloak - Resistance
[1888]  = {-20014,    nil, 5, HOLY_RES, 5, FIRE_RES, 5, NATURE_RES, 5, FROST_RES, 5, SHADOW_RES, 5, ARCANE_RES}, -- Enchant Cloak - Greater Resistance
[783]   = { -7771,    nil, 10, ARMOR}, -- Enchant Cloak - Minor Protection
[744]   = {-13421,    nil, 20, ARMOR}, -- Enchant Cloak - Lesser Protection
[848]   = {-13635,    nil, 30, ARMOR}, -- Enchant Cloak - Defense
[884]   = {-13746,    nil, 50, ARMOR}, -- Enchant Cloak - Greater Defense
[1889]  = {-20015,    nil, 70, ARMOR}, -- Enchant Cloak - Superior Defense
[256]   = { -7861,    nil, 5, FIRE_RES}, -- Enchant Cloak - Lesser Fire Resistance
[2463]  = {-13657,    nil, 7, FIRE_RES}, -- Enchant Cloak - Fire Resistance
[2619]  = {-25081,    nil, 15, FIRE_RES}, -- Enchant Cloak - Greater Fire Resistance
[2620]  = {-25082,    nil, 15, NATURE_RES}, -- Enchant Cloak - Greater Nature Resistance
[804]   = {-13522,    nil, 10, SHADOW_RES}, -- Enchant Cloak - Lesser Shadow Resistance
[910]   = {-25083,    nil, 8, AGILITY, 8, DODGE}, -- Enchant Cloak - Stealth
[2621]  = {-25084,    nil, 0, EFFECT}, -- Enchant Cloak - Subtlety

-- ------------------------------------------------------------------------------------------------------------------ --
-- WAIST                                                                                                              --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Engineers Only
[4214]  = {-84425,    nil, 0, EFFECT}, -- Cardboard Assassin
[4188]  = {-84427,    nil, 0, EFFECT}, -- Grounded Plasma Shield
[4187]  = {-84424,    nil, 0, EFFECT}, -- Invisibility Field
-- Wrath ========================================
-- - Engineers Only
[3599]  = {-54736,    nil, 0, EFFECT}, -- Personal Electromagnetic Pulse Generator
[3601]  = {-54793,    nil, 0, EFFECT}, -- Belt-Clipped Spynoculars
[3878]  = {-67839,    nil, 0, EFFECT}, -- Mind Amplification Dish
[4223]  = {-55016,    nil, 0, EFFECT}, -- Nitro Boosts

-- ------------------------------------------------------------------------------------------------------------------ --
-- SHIELD                                                                                                             --
-- ------------------------------------------------------------------------------------------------------------------ --
--Cata ========================================
-- - Enchanting
[4073]  = {-74207,    nil, 160, ARMOR}, -- Enchant Shield - Protection
[4085]  = {-74226,    nil, 40, BLOCK}, -- Enchant Shield - Blocking
-- - Blacksmithing
[4215]  = { 55055,    nil, 0, EFFECT}, -- Elementium Shield Spike
[4216]  = { 55056,    nil, 0, EFFECT}, -- Pyrium Shield Spike
-- Wrath ========================================
-- - Enchanting
[1952]  = {-44489,    nil, 20, DODGE}, -- Enchant Shield - Defense
[1128]  = {-60653,    nil, 25, INTELLECT}, -- Enchant Shield - Greater Intellect
-- - Blacksmithing
[3748]  = { 42500,    nil, 0, EFFECT}, -- Titanium Shield Spike
[3849]  = { 44936,    nil, 26, PARRY, 0, EFFECT}, -- Titanium Plating
-- BC ========================================
-- - Enchanting
[1888]  = {-27947,    nil, 5, HOLY_RES, 5, FIRE_RES, 5, NATURE_RES, 5, FROST_RES, 5, SHADOW_RES, 5, ARCANE_RES}, -- Enchant Shield - Resistance
[2653]  = {-27944,    nil, 12, DODGE}, -- Enchant Shield - Tough Shield
[2654]  = {-27945,    nil, 12, INTELLECT}, -- Enchant Shield - Intellect
[3229]  = {-44383,    nil, 12, RESILIENCE}, -- Enchant Shield - Resilience
[2655]  = {-27946,    nil, 15, PARRY}, -- Enchant Shield - Shield Block
[1071]  = {-34009,    nil, 18, STAMINA}, -- Enchant Shield - Major Stamina
-- - Blacksmithing
[2714]  = { 23530,    nil, 0, EFFECT}, -- Felsteel Shield Spike
-- Classic ========================================
-- - Enchanting
[848]   = {-13464,    nil, 10, ARMOR}, -- Enchant Shield - Lesser Protection
[926]   = {-13933,    nil, 8, FROST_RES}, -- Enchant Shield - Frost Resistance
[863]   = {-13689,    nil, 10, PARRY}, -- Enchant Shield - Lesser Block
[255]   = {-13485,    nil, 3, SPIRIT}, -- Enchant Shield - Lesser Spirit
[851]   = {-13659,    nil, 5, SPIRIT}, -- Enchant Shield - Spirit
[907]   = {-13905,    nil, 7, SPIRIT}, -- Enchant Shield - Greater Spirit
--TODO [1890]  = {-20016,    nil}, -- Enchant Shield - Vitality
[66]    = {-13378,    nil, 1, STAMINA}, -- Enchant Shield - Minor Stamina
[724]   = {-13631,    nil, 3, STAMINA}, -- Enchant Shield - Lesser Stamina
[852]   = {-13817,    nil, 5, STAMINA}, -- Enchant Shield - Stamina
[929]   = {-20017,    nil, 7, STAMINA}, -- Enchant Shield - Greater Stamina
--  Blacksmithing
[43]    = {  6042,    nil, 0, EFFECT}, -- Iron Shield Spike
[463]   = {  7967,    nil, 0, EFFECT}, -- Mithril Shield Spike
[1704]  = { 12645,    nil, 0, EFFECT}, -- Thorium Shield Spike

-- ------------------------------------------------------------------------------------------------------------------ --
-- WEAPON                                                                                                             --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
-- - Enchanting (Weapon)
[4098]  = {-74244,    nil, 0, EFFECT}, -- Enchant Weapon - Windwalk   ---NOTE: sometimes increase dodge rating by 600 and movement speed by 15% for 10 sec when striking in melee
[4097]  = {-74242,    nil, 0, EFFECT}, -- Enchant Weapon - Power Torrent   ---NOTE: sometimes increase Intellect by 500 for 12 sec when dealing damage or healing with spells
[4066]  = {-74195,    nil, 0, EFFECT}, -- Enchant Weapon - Mending   ---NOTE: sometimes heal you when damaging an enemy with spells and melee attacks
[4099]  = {-74246,    nil, 0, EFFECT}, -- Enchant Weapon - Landslide   ---NOTE: sometimes increase attack power by 1000 for 12 sec when striking in melee
[4083]  = {-74223,    nil, 0, EFFECT}, -- Enchant Weapon - Hurricane   ---NOTE: sometimes increase haste rating by 450 for 12 sec when casting spells or dealing melee damage
[4084]  = {-74225,    nil, 0, EFFECT}, -- Enchant Weapon - Heartsong   ---NOTE: sometimes increase Spirit by 200 for 15 sec when casting spell
[4074]  = {-74211,    nil, 0, EFFECT}, -- Enchant Weapon - Elemental Slayer   ---NOTE: sometimes disrupt elementals when struck by your melee attacks, dealing Arcane damage and silencing them for 5 sec
[4067]  = {-74197,    nil, 0, EFFECT}, -- Enchant Weapon - Avalanche   ---NOTE: often deal 463 to 537 Nature damage to an enemy struck by your melee attacks
-- - Enchanting (Off-Hand)
[4091]  = {-74235,    nil, 40, INTELLECT}, -- Enchant Off-Hand - Superior Intellect
-- - Enchanting (2H Weapon)
[4227]  = {-95471,    nil, 130, AGILITY}, -- Enchant 2H Weapon - Mighty Agility
-- - Blacksmithing
[4217]  = { 55057,    nil, 40, HIT, 0, EFFECT}, -- Pyrium Weapon Chain
-- Wrath ========================================
-- - Enchanting (Weapon)
[1103]  = {-44633,    nil, 26, AGILITY}, -- Enchant Weapon - Exceptional Agility
[1606]  = {-60621,    nil, 50, ATTACKPOWER}, -- Enchant Weapon - Greater Potency
[3833]  = {-60707,    nil, 65, ATTACKPOWER}, -- Enchant Weapon - Superior Potency
[3788]  = {-59619,    nil, 25, HIT, 25, CRIT}, -- Enchant Weapon - Accuracy
[3789]  = {-59621,    nil, 0, EFFECT}, -- Enchant Weapon - Berserking   ---NOTE: sometimes increase your attack power by 400, but at the cost of reduced armor
[3869]  = {-64441,    nil, 0, EFFECT}, -- Enchant Weapon - Blade Ward   ---NOTE: sometimes grant Blade Warding when striking an enemy.  Blade Warding increases your parry rating by 200 and inflicts 600 to 800 damage on your next parry
[3251]  = {-44621,    nil, 0, EFFECT}, -- Enchant Weapon - Giant Slayer   ---NOTE: have a chance of reducing movement speed and doing additional damage against giants
[3241]  = {-44576,    nil, 0, EFFECT}, -- Enchant Weapon - Lifeward   ---NOTE: sometimes heal the wielder when striking in melee
[3239]  = {-44524,    nil, 0, EFFECT}, -- Enchant Weapon - Icebreaker   ---NOTE: sometimes inflict fire damage
[3870]  = {-64579,    nil, 0, EFFECT}, -- Enchant Weapon - Blood Draining   ---NOTE: sometimes grant Blood Reserve when striking an enemy or inflicting damage with bleed attacks
[3790]  = {-59625,    nil, 0, EFFECT}, -- Enchant Weapon - Black Magic   ---NOTE: sometimes increase haste rating by 250
[3830]  = {-44629,    nil, 50, SPELLPOWER}, -- Enchant Weapon - Exceptional Spellpower
[3834]  = {-60714,    nil, 63, SPELLPOWER}, -- Enchant Weapon - Mighty Spellpower
[3844]  = {-44510,    nil, 45, SPIRIT}, -- Enchant Weapon - Exceptional Spirit
-- - Enchanting (2H Weapon)
[3828]  = {-44630,    nil, 85, ATTACKPOWER}, -- Enchant 2H Weapon - Greater Savagery
[3827]  = {-60691,    nil, 110, ATTACKPOWER}, -- Enchant 2H Weapon - Massacre
[3247]  = {-44595,    nil, 0, EFFECT}, -- Enchant 2H Weapon - Scourgebane   ---NOTE: +140 Attack Power versus Undead
[2670]  = {-27977,    nil, 35, AGILITY}, -- Enchant 2H Weapon - Major Agility
[2667]  = {-27971,    nil, 70, ATTACKPOWER}, -- Enchant 2H Weapon - Savagery
[3855]  = {-62959,    nil, 69, SPELLPOWER}, -- Enchant Staff - Spellpower
[3854]  = {-62948,    nil, 81, SPELLPOWER}, -- Enchant Staff - Greater Spellpower
-- - Blacksmithing
[3731]  = { 41976,    nil, 28, HIT, 0, EFFECT}, -- Titanium Weapon Chain
-- BC ========================================
-- - Enchanting (Weapon)
[3222]  = {-42620,    nil, 20, AGILITY}, -- Enchant Weapon - Greater Agility
-- TODO [963]   = {-27967,    nil}, -- Enchant Weapon - Major Striking
[2671]  = {-27981,    nil, 0, EFFECT}, -- Enchant Weapon - Sunfire   ---NOTE: +50 Arcane and Fire Spell Power
[2672]  = {-27982,    nil, 0, EFFECT}, -- Enchant Weapon - Soulfrost   ---NOTE: +54 Shadow and Frost Spell Power
[2666]  = {-27968,    nil, 30, INTELLECT}, -- Enchant Weapon - Major Intellect
[2673]  = {-27984,    nil, 0, EFFECT}, -- Enchant Weapon - Mongoose   ---NOTE: occasionally increase Agility by 120 and attack speed slightly
[3225]  = {-42974,    nil, 0, EFFECT}, -- Enchant Weapon - Executioner   ---NOTE: occasionally grant you 120 critical strike rating
[2675]  = {-28004,    nil, 0, EFFECT}, -- Enchant Weapon - Battlemaster   ---NOTE: occasionally heal nearby party members for 180 to 300 when attacking in melee
[3273]  = {-46578,    nil, 0, EFFECT}, -- Enchant Weapon - Deathfrost   ---NOTE: occasionally inflict additional Frost damage and slow the target
[3846]  = {-34010,    nil, 40, SPELLPOWER}, -- Enchant Weapon - Major Healing
[2669]  = {-27975,    nil, 40, SPELLPOWER}, -- Enchant Weapon - Major Spellpower
[2674]  = {-28003,    nil, 0, EFFECT}, -- Enchant Weapon - Spellsurge   ---NOTE: make your spells sometimes restore 100 mana to nearby party members
[2668]  = {-27972,    nil, 20, STRENGTH}, -- Enchant Weapon - Potency
-- - Blacksmithing
[3223]  = { 33185,    nil, 15, PARRY, 0, EFFECT}, -- Adamantite Weapon Chain
-- Classic ========================================
-- - Enchanting (Weapon)
[2564]  = {-23800,    nil, 15, AGILITY}, -- Enchant Weapon - Agility
-- TODO [250]   = { -7788,    nil}, -- Enchant Weapon - Minor Striking
-- TODO [241]   = {-13503,    nil}, -- Enchant Weapon - Lesser Striking
-- TODO [943]   = {-13693,    nil}, -- Enchant Weapon - Striking
-- TODO [805]   = {-13943,    nil}, -- Enchant Weapon - Greater Striking
-- TODO [1897]  = {-20031,    nil}, -- Enchant Weapon - Superior Striking
[249]   = { -7786,    nil, 0, EFFECT}, -- Enchant Weapon - Minor Beastslayer   ---NOTE: do 2 additional points of damage to beasts
[853]   = {-13653,    nil, 0, EFFECT}, -- Enchant Weapon - Lesser Beastslayer   ---NOTE: increase its damage to beasts by 6
[854]   = {-13655,    nil, 0, EFFECT}, -- Enchant Weapon - Lesser Elemental Slayer   ---NOTE: increase its damage to elementals by 6
[2443]  = {-21931,    nil, 0, EFFECT}, -- Enchant Weapon - Winter's Might   ---NOTE: increase Frost spell power by 7
[1894]  = {-20029,    nil, 0, EFFECT}, -- Enchant Weapon - Icy Chill   ---NOTE: often chill the target, reducing their movement and attack speed
[1899]  = {-20033,    nil, 0, EFFECT}, -- Enchant Weapon - Unholy Weapon   ---NOTE: often inflict a curse on the target, inflicting Shadow damage and reducing their melee damage
[1898]  = {-20032,    nil, 0, EFFECT}, -- Enchant Weapon - Lifestealing   ---NOTE: often steal life from the enemy and give it to the wielder
[803]   = {-13898,    nil, 0, EFFECT}, -- Enchant Weapon - Fiery Weapon   ---NOTE: often strike for 40 additional fire damage
[1900]  = {-20034,    nil, 0, EFFECT}, -- Enchant Weapon - Crusader   ---NOTE: often heal for 75 to 125 and increase Strength by 100 for 15 sec. when attacking in melee
[912]   = {-13915,    nil, 0, EFFECT}, -- Enchant Weapon - Demonslaying   ---NOTE: have a chance of stunning and doing additional damage against demons
[2568]  = {-23804,    nil, 22, INTELLECT}, -- Enchant Weapon - Mighty Intellect
[2505]  = {-22750,    nil, 29, SPELLPOWER}, -- Enchant Weapon - Healing Power
[2504]  = {-22749,    nil, 30, SPELLPOWER}, -- Enchant Weapon - Spell Power
[2567]  = {-23803,    nil, 20, SPIRIT}, -- Enchant Weapon - Mighty Spirit
[2563]  = {-23799,    nil, 15, STRENGTH}, -- Enchant Weapon - Strength
-- - Enchanting (2H Weapon)
[2646]  = {-27837,    nil, 25, AGILITY}, -- Enchant 2H Weapon - Agility
-- TODO [241]   = { -7745,    nil}, -- Enchant 2H Weapon - Minor Impact
-- TODO [943]   = {-13529,    nil}, -- Enchant 2H Weapon - Lesser Impact
-- TODO [1897]  = {-13695,    nil}, -- Enchant 2H Weapon - Impact
-- TODO [963]   = {-13937,    nil}, -- Enchant 2H Weapon - Greater Impact
-- TODO [1896]  = {-20030,    nil}, -- Enchant 2H Weapon - Superior Impact
[723]   = { -7793,    nil, 3, INTELLECT}, -- Enchant 2H Weapon - Lesser Intellect
[1904]  = {-20036,    nil, 9, INTELLECT}, -- Enchant 2H Weapon - Major Intellect
[255]   = {-13380,    nil, 3, SPIRIT}, -- Enchant 2H Weapon - Lesser Spirit
[1903]  = {-20035,    nil, 9, SPIRIT}, -- Enchant 2H Weapon - Major Spirit
-- - Blacksmithing
[34]    = {  6043,    nil, 20, HASTE}, -- Iron Counterweight
[37]    = {  6041,    nil, 0, EFFECT}, -- Steel Weapon Chain

-- Runeforging
[3369]  = {-53341,    nil, 0, EFFECT}, -- Rune of Cinderglacier (lvl 55)
[3370]  = {-53343,    nil, 0, EFFECT}, -- Rune of Razorice (lvl 55)
[3595]  = {-54447,    nil, 0, EFFECT}, -- Rune of Spellbreaking (lvl 57)
[3367]  = {-53342,    nil, 0, EFFECT}, -- Rune of Spellshattering (lvl 57)
[3366]  = {-53331,    nil, 0, EFFECT}, -- Rune of Lichbane (lvl 60)
[3594]  = {-54446,    nil, 0, EFFECT}, -- Rune of Swordbreaking (lvl 63)
[3365]  = {-53323,    nil, 0, EFFECT}, -- Rune of Swordshattering (lvl 63)
[3368]  = {-53344,    nil, 0, EFFECT}, -- Rune of the Fallen Crusader (lvl 70)
[3883]  = {-70164,    nil, 0, EFFECT}, -- Rune of the Nerubian Carapace (lvl 72)
[3847]  = {-62158,    nil, 0, EFFECT}, -- Rune of the Stoneskin Gargoyle (lvl 72)

-- Fishing
[3269]  = { 34836,    nil, 0, EFFECT}, -- Spun Truesilver Fishing Line (+3 Fishing)
[846]   = { 19971,    nil, 0, EFFECT}, -- High Test Eternium Fishing Line (+5 Fishing)   ---same enchantID as Enchant Gloves - Angler (+5 Fishing)!---
[4259]  = { 68796,    nil, 0, EFFECT}, -- Reinforced Fishing Line (+1 Fishing)

-- Quest
[36]    = {  5421,    nil, 0, EFFECT}, -- Fiery Blaze Enchantment

-- ------------------------------------------------------------------------------------------------------------------ --
-- INVTYPE_RANGED                                                                                                     --
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata ========================================
[4267]  = { 70139,    nil, 0, EFFECT}, -- Flintlocke's Woodchucker
[4177]  = { 59596,    nil, 88, HASTE_RANGED}, -- Safety Catch Removal Kit
[4176]  = { 59595,    nil, 88, HIT_RANGED}, -- R19 Threatfinder
-- Wrath ========================================
-- TODO [3843]  = { 44739,    nil}, -- Diamond-cut Refractor Scope
[3608]  = { 41167,    nil, 40, CRIT_RANGED}, -- Heartseeker Scope
[3607]  = { 41146,    nil, 40, HASTE_RANGED}, -- Sun Scope
-- BC ========================================
-- TODO [2722]  = { 23764,    nil}, -- Adamantite Scope
-- TODO [2723]  = { 23765,    nil}, -- Khorium Scope
[2724]  = { 23766,    nil, 26, CRIT_RANGED}, -- Stabilized Eternium Scope
-- Classic ========================================
-- TODO [30]    = {  4405,    nil}, -- Crude Scope
-- TODO [32]    = {  4406,    nil}, -- Standard Scope
-- TODO [33]    = {  4407,    nil}, -- Accurate Scope
-- TODO [663]   = { 10546,    nil}, -- Deadly Scope
-- TODO [664]   = { 10548,    nil}, -- Sniper Scope
[2523]  = { 18283,    nil, 30, HIT_RANGED}, -- Biznicks 247x128 Accurascope
}


function CharScanner_GearStats_Enchantment(id)
	--    1    2    3     4      5     6      7     8      9     10     11    12     13    14
	local aid, hid, val1, stat1, val2, stat2, val3, stat3, val4, stat4, val5, stat5, val6, stat6
	if enchantIDs[id] then
		aid = enchantIDs[id][1]
		hid = enchantIDs[id][2]
		if enchantIDs[id][3] then
			val1  = enchantIDs[id][3]
			stat1 = enchantIDs[id][4]
			if enchantIDs[id][5] then
				val2  = enchantIDs[id][5]
				stat2 = enchantIDs[id][6]
				if enchantIDs[id][7] then
					val3  = enchantIDs[id][7]
					stat3 = enchantIDs[id][8]
					if enchantIDs[id][9] then
						val4  = enchantIDs[id][9]
						stat4 = enchantIDs[id][10]
						if enchantIDs[id][11] then
							val5  = enchantIDs[id][11]
							stat5 = enchantIDs[id][12]
							if enchantIDs[id][13] then
								val6  = enchantIDs[id][13]
								stat6 = enchantIDs[id][14]
							end
						end
					end
				end
			end
		end
	end
	return aid, hid, val1, stat1, val2, stat2, val3, stat3, val4, stat4, val5, stat5, val6, stat6
end